@@ -2,14 +2,16 @@
 -module(diameter_dict_parser).
 -file("gen/diameter_dict_parser.erl", 3).
 -export([parse/1, parse_and_scan/1, format_error/1]).
--file("compiler/diameter_dict_parser.yrl", 327).
+-file("compiler/diameter_dict_parser.yrl", 329).
 -moduledoc false.
 
--file("/var/tmp/portage/dev-lang/erlang-27.3.4.6/work/otp-OTP-27.3.4.6/bootstrap/lib/parsetools/include/yeccpre.hrl", 0).
+-file("/var/tmp/portage/dev-lang/erlang-28.1/work/otp-OTP-28.1/bootstrap/lib/parsetools/include/yeccpre.hrl", 0).
 %%
 %% %CopyrightBegin%
 %%
-%% Copyright Ericsson AB 1996-2024. All Rights Reserved.
+%% SPDX-License-Identifier: Apache-2.0
+%%
+%% Copyright Ericsson AB 1996-2025. All Rights Reserved.
 %%
 %% Licensed under the Apache License, Version 2.0 (the "License");
 %% you may not use this file except in compliance with the License.
@@ -193,7 +195,7 @@ yecctoken2string1(Other) ->
 
 
 
--file("gen/diameter_dict_parser.erl", 196).
+-file("gen/diameter_dict_parser.erl", 198).
 
 -dialyzer({nowarn_function, yeccpars2/7}).
 -compile({nowarn_unused_function,  yeccpars2/7}).
@@ -1749,7 +1751,7 @@ yeccgoto_sections(2=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 -compile({inline,yeccpars2_0_/1}).
 -dialyzer({nowarn_function, yeccpars2_0_/1}).
 -compile({nowarn_unused_function,  yeccpars2_0_/1}).
--file("compiler/diameter_dict_parser.yrl", 48).
+-file("compiler/diameter_dict_parser.yrl", 50).
 yeccpars2_0_(__Stack0) ->
  [begin
                                []
@@ -1758,7 +1760,7 @@ yeccpars2_0_(__Stack0) ->
 -compile({inline,yeccpars2_1_/1}).
 -dialyzer({nowarn_function, yeccpars2_1_/1}).
 -compile({nowarn_unused_function,  yeccpars2_1_/1}).
--file("compiler/diameter_dict_parser.yrl", 46).
+-file("compiler/diameter_dict_parser.yrl", 48).
 yeccpars2_1_(__Stack0) ->
  [___1 | __Stack] = __Stack0,
  [begin
@@ -1768,7 +1770,7 @@ yeccpars2_1_(__Stack0) ->
 -compile({inline,yeccpars2_2_/1}).
 -dialyzer({nowarn_function, yeccpars2_2_/1}).
 -compile({nowarn_unused_function,  yeccpars2_2_/1}).
--file("compiler/diameter_dict_parser.yrl", 48).
+-file("compiler/diameter_dict_parser.yrl", 50).
 yeccpars2_2_(__Stack0) ->
  [begin
                                []
@@ -1777,7 +1779,7 @@ yeccpars2_2_(__Stack0) ->
 -compile({inline,yeccpars2_4_/1}).
 -dialyzer({nowarn_function, yeccpars2_4_/1}).
 -compile({nowarn_unused_function,  yeccpars2_4_/1}).
--file("compiler/diameter_dict_parser.yrl", 71).
+-file("compiler/diameter_dict_parser.yrl", 73).
 yeccpars2_4_(__Stack0) ->
  [begin
                                []
@@ -1786,7 +1788,7 @@ yeccpars2_4_(__Stack0) ->
 -compile({inline,yeccpars2_10_/1}).
 -dialyzer({nowarn_function, yeccpars2_10_/1}).
 -compile({nowarn_unused_function,  yeccpars2_10_/1}).
--file("compiler/diameter_dict_parser.yrl", 97).
+-file("compiler/diameter_dict_parser.yrl", 99).
 yeccpars2_10_(__Stack0) ->
  [begin
                                      []
@@ -1795,7 +1797,7 @@ yeccpars2_10_(__Stack0) ->
 -compile({inline,yeccpars2_13_/1}).
 -dialyzer({nowarn_function, yeccpars2_13_/1}).
 -compile({nowarn_unused_function,  yeccpars2_13_/1}).
--file("compiler/diameter_dict_parser.yrl", 100).
+-file("compiler/diameter_dict_parser.yrl", 102).
 yeccpars2_13_(__Stack0) ->
  [begin
                                            []
@@ -1804,7 +1806,7 @@ yeccpars2_13_(__Stack0) ->
 -compile({inline,yeccpars2_18_/1}).
 -dialyzer({nowarn_function, yeccpars2_18_/1}).
 -compile({nowarn_unused_function,  yeccpars2_18_/1}).
--file("compiler/diameter_dict_parser.yrl", 54).
+-file("compiler/diameter_dict_parser.yrl", 56).
 yeccpars2_18_(__Stack0) ->
  [___3,___2,___1 | __Stack] = __Stack0,
  [begin
@@ -1814,7 +1816,7 @@ yeccpars2_18_(__Stack0) ->
 -compile({inline,yeccpars2_19_/1}).
 -dialyzer({nowarn_function, yeccpars2_19_/1}).
 -compile({nowarn_unused_function,  yeccpars2_19_/1}).
--file("compiler/diameter_dict_parser.yrl", 90).
+-file("compiler/diameter_dict_parser.yrl", 92).
 yeccpars2_19_(__Stack0) ->
  [___1 | __Stack] = __Stack0,
  [begin
@@ -1824,7 +1826,7 @@ yeccpars2_19_(__Stack0) ->
 -compile({inline,yeccpars2_20_/1}).
 -dialyzer({nowarn_function, yeccpars2_20_/1}).
 -compile({nowarn_unused_function,  yeccpars2_20_/1}).
--file("compiler/diameter_dict_parser.yrl", 52).
+-file("compiler/diameter_dict_parser.yrl", 54).
 yeccpars2_20_(__Stack0) ->
  [___2,___1 | __Stack] = __Stack0,
  [begin
@@ -1834,7 +1836,7 @@ yeccpars2_20_(__Stack0) ->
 -compile({inline,yeccpars2_21_/1}).
 -dialyzer({nowarn_function, yeccpars2_21_/1}).
 -compile({nowarn_unused_function,  yeccpars2_21_/1}).
--file("compiler/diameter_dict_parser.yrl", 51).
+-file("compiler/diameter_dict_parser.yrl", 53).
 yeccpars2_21_(__Stack0) ->
  [___2,___1 | __Stack] = __Stack0,
  [begin
@@ -1844,7 +1846,7 @@ yeccpars2_21_(__Stack0) ->
 -compile({inline,yeccpars2_22_/1}).
 -dialyzer({nowarn_function, yeccpars2_22_/1}).
 -compile({nowarn_unused_function,  yeccpars2_22_/1}).
--file("compiler/diameter_dict_parser.yrl", 60).
+-file("compiler/diameter_dict_parser.yrl", 62).
 yeccpars2_22_(__Stack0) ->
  [___2,___1 | __Stack] = __Stack0,
  [begin
@@ -1854,7 +1856,7 @@ yeccpars2_22_(__Stack0) ->
 -compile({inline,yeccpars2_23_/1}).
 -dialyzer({nowarn_function, yeccpars2_23_/1}).
 -compile({nowarn_unused_function,  yeccpars2_23_/1}).
--file("compiler/diameter_dict_parser.yrl", 137).
+-file("compiler/diameter_dict_parser.yrl", 139).
 yeccpars2_23_(__Stack0) ->
  [___1 | __Stack] = __Stack0,
  [begin
@@ -1864,7 +1866,7 @@ yeccpars2_23_(__Stack0) ->
 -compile({inline,yeccpars2_25_/1}).
 -dialyzer({nowarn_function, yeccpars2_25_/1}).
 -compile({nowarn_unused_function,  yeccpars2_25_/1}).
--file("compiler/diameter_dict_parser.yrl", 100).
+-file("compiler/diameter_dict_parser.yrl", 102).
 yeccpars2_25_(__Stack0) ->
  [begin
                                            []
@@ -1893,7 +1895,7 @@ yeccpars2_32_(__Stack0) ->
 -compile({inline,yeccpars2_40_/1}).
 -dialyzer({nowarn_function, yeccpars2_40_/1}).
 -compile({nowarn_unused_function,  yeccpars2_40_/1}).
--file("compiler/diameter_dict_parser.yrl", 203).
+-file("compiler/diameter_dict_parser.yrl", 205).
 yeccpars2_40_(__Stack0) ->
  [begin
                    []
@@ -1902,7 +1904,7 @@ yeccpars2_40_(__Stack0) ->
 -compile({inline,yeccpars2_42_/1}).
 -dialyzer({nowarn_function, yeccpars2_42_/1}).
 -compile({nowarn_unused_function,  yeccpars2_42_/1}).
--file("compiler/diameter_dict_parser.yrl", 128).
+-file("compiler/diameter_dict_parser.yrl", 130).
 yeccpars2_42_(__Stack0) ->
  [___13,___12,___11,___10,___9,___8,___7,___6,___5,___4,___3,___2,___1 | __Stack] = __Stack0,
  [begin
@@ -1912,7 +1914,7 @@ yeccpars2_42_(__Stack0) ->
 -compile({inline,yeccpars2_43_/1}).
 -dialyzer({nowarn_function, yeccpars2_43_/1}).
 -compile({nowarn_unused_function,  yeccpars2_43_/1}).
--file("compiler/diameter_dict_parser.yrl", 206).
+-file("compiler/diameter_dict_parser.yrl", 208).
 yeccpars2_43_(__Stack0) ->
  [___1 | __Stack] = __Stack0,
  [begin
@@ -1922,7 +1924,7 @@ yeccpars2_43_(__Stack0) ->
 -compile({inline,yeccpars2_44_/1}).
 -dialyzer({nowarn_function, yeccpars2_44_/1}).
 -compile({nowarn_unused_function,  yeccpars2_44_/1}).
--file("compiler/diameter_dict_parser.yrl", 203).
+-file("compiler/diameter_dict_parser.yrl", 205).
 yeccpars2_44_(__Stack0) ->
  [begin
                    []
@@ -1931,7 +1933,7 @@ yeccpars2_44_(__Stack0) ->
 -compile({inline,yeccpars2_45_/1}).
 -dialyzer({nowarn_function, yeccpars2_45_/1}).
 -compile({nowarn_unused_function,  yeccpars2_45_/1}).
--file("compiler/diameter_dict_parser.yrl", 242).
+-file("compiler/diameter_dict_parser.yrl", 244).
 yeccpars2_45_(__Stack0) ->
  [___1 | __Stack] = __Stack0,
  [begin
@@ -1941,7 +1943,7 @@ yeccpars2_45_(__Stack0) ->
 -compile({inline,yeccpars2_50_/1}).
 -dialyzer({nowarn_function, yeccpars2_50_/1}).
 -compile({nowarn_unused_function,  yeccpars2_50_/1}).
--file("compiler/diameter_dict_parser.yrl", 249).
+-file("compiler/diameter_dict_parser.yrl", 251).
 yeccpars2_50_(__Stack0) ->
  [___1 | __Stack] = __Stack0,
  [begin
@@ -1951,7 +1953,7 @@ yeccpars2_50_(__Stack0) ->
 -compile({inline,yeccpars2_51_/1}).
 -dialyzer({nowarn_function, yeccpars2_51_/1}).
 -compile({nowarn_unused_function,  yeccpars2_51_/1}).
--file("compiler/diameter_dict_parser.yrl", 258).
+-file("compiler/diameter_dict_parser.yrl", 260).
 yeccpars2_51_(__Stack0) ->
  [___1 | __Stack] = __Stack0,
  [begin
@@ -1961,7 +1963,7 @@ yeccpars2_51_(__Stack0) ->
 -compile({inline,yeccpars2_53_/1}).
 -dialyzer({nowarn_function, yeccpars2_53_/1}).
 -compile({nowarn_unused_function,  yeccpars2_53_/1}).
--file("compiler/diameter_dict_parser.yrl", 257).
+-file("compiler/diameter_dict_parser.yrl", 259).
 yeccpars2_53_(__Stack0) ->
  [___1 | __Stack] = __Stack0,
  [begin
@@ -1971,7 +1973,7 @@ yeccpars2_53_(__Stack0) ->
 -compile({inline,yeccpars2_54_/1}).
 -dialyzer({nowarn_function, yeccpars2_54_/1}).
 -compile({nowarn_unused_function,  yeccpars2_54_/1}).
--file("compiler/diameter_dict_parser.yrl", 210).
+-file("compiler/diameter_dict_parser.yrl", 212).
 yeccpars2_54_(__Stack0) ->
  [___3,___2,___1 | __Stack] = __Stack0,
  [begin
@@ -1981,7 +1983,7 @@ yeccpars2_54_(__Stack0) ->
 -compile({inline,yeccpars2_55_/1}).
 -dialyzer({nowarn_function, yeccpars2_55_/1}).
 -compile({nowarn_unused_function,  yeccpars2_55_/1}).
--file("compiler/diameter_dict_parser.yrl", 240).
+-file("compiler/diameter_dict_parser.yrl", 242).
 yeccpars2_55_(__Stack0) ->
  [___2,___1 | __Stack] = __Stack0,
  [begin
@@ -1991,7 +1993,7 @@ yeccpars2_55_(__Stack0) ->
 -compile({inline,yeccpars2_56_/1}).
 -dialyzer({nowarn_function, yeccpars2_56_/1}).
 -compile({nowarn_unused_function,  yeccpars2_56_/1}).
--file("compiler/diameter_dict_parser.yrl", 239).
+-file("compiler/diameter_dict_parser.yrl", 241).
 yeccpars2_56_(__Stack0) ->
  [___3,___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2001,7 +2003,7 @@ yeccpars2_56_(__Stack0) ->
 -compile({inline,yeccpars2_58_/1}).
 -dialyzer({nowarn_function, yeccpars2_58_/1}).
 -compile({nowarn_unused_function,  yeccpars2_58_/1}).
--file("compiler/diameter_dict_parser.yrl", 211).
+-file("compiler/diameter_dict_parser.yrl", 213).
 yeccpars2_58_(__Stack0) ->
  [___3,___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2011,7 +2013,7 @@ yeccpars2_58_(__Stack0) ->
 -compile({inline,yeccpars2_60_/1}).
 -dialyzer({nowarn_function, yeccpars2_60_/1}).
 -compile({nowarn_unused_function,  yeccpars2_60_/1}).
--file("compiler/diameter_dict_parser.yrl", 209).
+-file("compiler/diameter_dict_parser.yrl", 211).
 yeccpars2_60_(__Stack0) ->
  [___3,___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2021,7 +2023,7 @@ yeccpars2_60_(__Stack0) ->
 -compile({inline,yeccpars2_61_/1}).
 -dialyzer({nowarn_function, yeccpars2_61_/1}).
 -compile({nowarn_unused_function,  yeccpars2_61_/1}).
--file("compiler/diameter_dict_parser.yrl", 241).
+-file("compiler/diameter_dict_parser.yrl", 243).
 yeccpars2_61_(__Stack0) ->
  [___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2031,7 +2033,7 @@ yeccpars2_61_(__Stack0) ->
 -compile({inline,yeccpars2_62_/1}).
 -dialyzer({nowarn_function, yeccpars2_62_/1}).
 -compile({nowarn_unused_function,  yeccpars2_62_/1}).
--file("compiler/diameter_dict_parser.yrl", 204).
+-file("compiler/diameter_dict_parser.yrl", 206).
 yeccpars2_62_(__Stack0) ->
  [___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2041,7 +2043,7 @@ yeccpars2_62_(__Stack0) ->
 -compile({inline,yeccpars2_63_/1}).
 -dialyzer({nowarn_function, yeccpars2_63_/1}).
 -compile({nowarn_unused_function,  yeccpars2_63_/1}).
--file("compiler/diameter_dict_parser.yrl", 207).
+-file("compiler/diameter_dict_parser.yrl", 209).
 yeccpars2_63_(__Stack0) ->
  [___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2051,7 +2053,7 @@ yeccpars2_63_(__Stack0) ->
 -compile({inline,yeccpars2_64_/1}).
 -dialyzer({nowarn_function, yeccpars2_64_/1}).
 -compile({nowarn_unused_function,  yeccpars2_64_/1}).
--file("compiler/diameter_dict_parser.yrl", 101).
+-file("compiler/diameter_dict_parser.yrl", 103).
 yeccpars2_64_(__Stack0) ->
  [___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2061,7 +2063,7 @@ yeccpars2_64_(__Stack0) ->
 -compile({inline,yeccpars2_66_/1}).
 -dialyzer({nowarn_function, yeccpars2_66_/1}).
 -compile({nowarn_unused_function,  yeccpars2_66_/1}).
--file("compiler/diameter_dict_parser.yrl", 203).
+-file("compiler/diameter_dict_parser.yrl", 205).
 yeccpars2_66_(__Stack0) ->
  [begin
                    []
@@ -2070,7 +2072,7 @@ yeccpars2_66_(__Stack0) ->
 -compile({inline,yeccpars2_70_/1}).
 -dialyzer({nowarn_function, yeccpars2_70_/1}).
 -compile({nowarn_unused_function,  yeccpars2_70_/1}).
--file("compiler/diameter_dict_parser.yrl", 173).
+-file("compiler/diameter_dict_parser.yrl", 175).
 yeccpars2_70_(__Stack0) ->
  [begin
                        []
@@ -2079,7 +2081,7 @@ yeccpars2_70_(__Stack0) ->
 -compile({inline,yeccpars2_71_/1}).
 -dialyzer({nowarn_function, yeccpars2_71_/1}).
 -compile({nowarn_unused_function,  yeccpars2_71_/1}).
--file("compiler/diameter_dict_parser.yrl", 166).
+-file("compiler/diameter_dict_parser.yrl", 168).
 yeccpars2_71_(__Stack0) ->
  [___1 | __Stack] = __Stack0,
  [begin
@@ -2089,7 +2091,7 @@ yeccpars2_71_(__Stack0) ->
 -compile({inline,yeccpars2_72_/1}).
 -dialyzer({nowarn_function, yeccpars2_72_/1}).
 -compile({nowarn_unused_function,  yeccpars2_72_/1}).
--file("compiler/diameter_dict_parser.yrl", 181).
+-file("compiler/diameter_dict_parser.yrl", 183).
 yeccpars2_72_(__Stack0) ->
  [begin
                              false
@@ -2098,7 +2100,7 @@ yeccpars2_72_(__Stack0) ->
 -compile({inline,yeccpars2_74_/1}).
 -dialyzer({nowarn_function, yeccpars2_74_/1}).
 -compile({nowarn_unused_function,  yeccpars2_74_/1}).
--file("compiler/diameter_dict_parser.yrl", 173).
+-file("compiler/diameter_dict_parser.yrl", 175).
 yeccpars2_74_(__Stack0) ->
  [begin
                        []
@@ -2107,7 +2109,7 @@ yeccpars2_74_(__Stack0) ->
 -compile({inline,yeccpars2_75_/1}).
 -dialyzer({nowarn_function, yeccpars2_75_/1}).
 -compile({nowarn_unused_function,  yeccpars2_75_/1}).
--file("compiler/diameter_dict_parser.yrl", 179).
+-file("compiler/diameter_dict_parser.yrl", 181).
 yeccpars2_75_(__Stack0) ->
  [___1 | __Stack] = __Stack0,
  [begin
@@ -2117,7 +2119,7 @@ yeccpars2_75_(__Stack0) ->
 -compile({inline,yeccpars2_76_/1}).
 -dialyzer({nowarn_function, yeccpars2_76_/1}).
 -compile({nowarn_unused_function,  yeccpars2_76_/1}).
--file("compiler/diameter_dict_parser.yrl", 178).
+-file("compiler/diameter_dict_parser.yrl", 180).
 yeccpars2_76_(__Stack0) ->
  [___1 | __Stack] = __Stack0,
  [begin
@@ -2127,7 +2129,7 @@ yeccpars2_76_(__Stack0) ->
 -compile({inline,yeccpars2_77_/1}).
 -dialyzer({nowarn_function, yeccpars2_77_/1}).
 -compile({nowarn_unused_function,  yeccpars2_77_/1}).
--file("compiler/diameter_dict_parser.yrl", 174).
+-file("compiler/diameter_dict_parser.yrl", 176).
 yeccpars2_77_(__Stack0) ->
  [___3,___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2137,7 +2139,7 @@ yeccpars2_77_(__Stack0) ->
 -compile({inline,yeccpars2_79_/1}).
 -dialyzer({nowarn_function, yeccpars2_79_/1}).
 -compile({nowarn_unused_function,  yeccpars2_79_/1}).
--file("compiler/diameter_dict_parser.yrl", 182).
+-file("compiler/diameter_dict_parser.yrl", 184).
 yeccpars2_79_(__Stack0) ->
  [___1 | __Stack] = __Stack0,
  [begin
@@ -2147,7 +2149,7 @@ yeccpars2_79_(__Stack0) ->
 -compile({inline,yeccpars2_80_/1}).
 -dialyzer({nowarn_function, yeccpars2_80_/1}).
 -compile({nowarn_unused_function,  yeccpars2_80_/1}).
--file("compiler/diameter_dict_parser.yrl", 164).
+-file("compiler/diameter_dict_parser.yrl", 166).
 yeccpars2_80_(__Stack0) ->
  [___7,___6,___5,___4,___3,___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2157,7 +2159,7 @@ yeccpars2_80_(__Stack0) ->
 -compile({inline,yeccpars2_81_/1}).
 -dialyzer({nowarn_function, yeccpars2_81_/1}).
 -compile({nowarn_unused_function,  yeccpars2_81_/1}).
--file("compiler/diameter_dict_parser.yrl", 131).
+-file("compiler/diameter_dict_parser.yrl", 133).
 yeccpars2_81_(__Stack0) ->
  [___4,___3,___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2167,7 +2169,7 @@ yeccpars2_81_(__Stack0) ->
 -compile({inline,yeccpars2_82_/1}).
 -dialyzer({nowarn_function, yeccpars2_82_/1}).
 -compile({nowarn_unused_function,  yeccpars2_82_/1}).
--file("compiler/diameter_dict_parser.yrl", 78).
+-file("compiler/diameter_dict_parser.yrl", 80).
 yeccpars2_82_(__Stack0) ->
  [begin
                          []
@@ -2176,7 +2178,7 @@ yeccpars2_82_(__Stack0) ->
 -compile({inline,yeccpars2_83_/1}).
 -dialyzer({nowarn_function, yeccpars2_83_/1}).
 -compile({nowarn_unused_function,  yeccpars2_83_/1}).
--file("compiler/diameter_dict_parser.yrl", 67).
+-file("compiler/diameter_dict_parser.yrl", 69).
 yeccpars2_83_(__Stack0) ->
  [___1 | __Stack] = __Stack0,
  [begin
@@ -2186,7 +2188,7 @@ yeccpars2_83_(__Stack0) ->
 -compile({inline,yeccpars2_84_/1}).
 -dialyzer({nowarn_function, yeccpars2_84_/1}).
 -compile({nowarn_unused_function,  yeccpars2_84_/1}).
--file("compiler/diameter_dict_parser.yrl", 69).
+-file("compiler/diameter_dict_parser.yrl", 71).
 yeccpars2_84_(__Stack0) ->
  [___1 | __Stack] = __Stack0,
  [begin
@@ -2196,7 +2198,7 @@ yeccpars2_84_(__Stack0) ->
 -compile({inline,yeccpars2_85_/1}).
 -dialyzer({nowarn_function, yeccpars2_85_/1}).
 -compile({nowarn_unused_function,  yeccpars2_85_/1}).
--file("compiler/diameter_dict_parser.yrl", 78).
+-file("compiler/diameter_dict_parser.yrl", 80).
 yeccpars2_85_(__Stack0) ->
  [begin
                          []
@@ -2205,7 +2207,7 @@ yeccpars2_85_(__Stack0) ->
 -compile({inline,yeccpars2_86_/1}).
 -dialyzer({nowarn_function, yeccpars2_86_/1}).
 -compile({nowarn_unused_function,  yeccpars2_86_/1}).
--file("compiler/diameter_dict_parser.yrl", 55).
+-file("compiler/diameter_dict_parser.yrl", 57).
 yeccpars2_86_(__Stack0) ->
  [___3,___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2215,7 +2217,7 @@ yeccpars2_86_(__Stack0) ->
 -compile({inline,yeccpars2_87_/1}).
 -dialyzer({nowarn_function, yeccpars2_87_/1}).
 -compile({nowarn_unused_function,  yeccpars2_87_/1}).
--file("compiler/diameter_dict_parser.yrl", 79).
+-file("compiler/diameter_dict_parser.yrl", 81).
 yeccpars2_87_(__Stack0) ->
  [___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2225,7 +2227,7 @@ yeccpars2_87_(__Stack0) ->
 -compile({inline,yeccpars2_88_/1}).
 -dialyzer({nowarn_function, yeccpars2_88_/1}).
 -compile({nowarn_unused_function,  yeccpars2_88_/1}).
--file("compiler/diameter_dict_parser.yrl", 53).
+-file("compiler/diameter_dict_parser.yrl", 55).
 yeccpars2_88_(__Stack0) ->
  [___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2235,7 +2237,7 @@ yeccpars2_88_(__Stack0) ->
 -compile({inline,yeccpars2_90_/1}).
 -dialyzer({nowarn_function, yeccpars2_90_/1}).
 -compile({nowarn_unused_function,  yeccpars2_90_/1}).
--file("compiler/diameter_dict_parser.yrl", 61).
+-file("compiler/diameter_dict_parser.yrl", 63).
 yeccpars2_90_(__Stack0) ->
  [___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2245,7 +2247,7 @@ yeccpars2_90_(__Stack0) ->
 -compile({inline,yeccpars2_91_/1}).
 -dialyzer({nowarn_function, yeccpars2_91_/1}).
 -compile({nowarn_unused_function,  yeccpars2_91_/1}).
--file("compiler/diameter_dict_parser.yrl", 97).
+-file("compiler/diameter_dict_parser.yrl", 99).
 yeccpars2_91_(__Stack0) ->
  [begin
                                      []
@@ -2254,7 +2256,7 @@ yeccpars2_91_(__Stack0) ->
 -compile({inline,yeccpars2_92_/1}).
 -dialyzer({nowarn_function, yeccpars2_92_/1}).
 -compile({nowarn_unused_function,  yeccpars2_92_/1}).
--file("compiler/diameter_dict_parser.yrl", 98).
+-file("compiler/diameter_dict_parser.yrl", 100).
 yeccpars2_92_(__Stack0) ->
  [___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2264,7 +2266,7 @@ yeccpars2_92_(__Stack0) ->
 -compile({inline,yeccpars2_94_/1}).
 -dialyzer({nowarn_function, yeccpars2_94_/1}).
 -compile({nowarn_unused_function,  yeccpars2_94_/1}).
--file("compiler/diameter_dict_parser.yrl", 203).
+-file("compiler/diameter_dict_parser.yrl", 205).
 yeccpars2_94_(__Stack0) ->
  [begin
                    []
@@ -2293,7 +2295,7 @@ yeccpars2_99_(__Stack0) ->
 -compile({inline,yeccpars2_101_/1}).
 -dialyzer({nowarn_function, yeccpars2_101_/1}).
 -compile({nowarn_unused_function,  yeccpars2_101_/1}).
--file("compiler/diameter_dict_parser.yrl", 320).
+-file("compiler/diameter_dict_parser.yrl", 322).
 yeccpars2_101_(__Stack0) ->
  [begin
                          false
@@ -2302,7 +2304,7 @@ yeccpars2_101_(__Stack0) ->
 -compile({inline,yeccpars2_102_/1}).
 -dialyzer({nowarn_function, yeccpars2_102_/1}).
 -compile({nowarn_unused_function,  yeccpars2_102_/1}).
--file("compiler/diameter_dict_parser.yrl", 318).
+-file("compiler/diameter_dict_parser.yrl", 320).
 yeccpars2_102_(__Stack0) ->
  [___1 | __Stack] = __Stack0,
  [begin
@@ -2312,7 +2314,7 @@ yeccpars2_102_(__Stack0) ->
 -compile({inline,yeccpars2_104_/1}).
 -dialyzer({nowarn_function, yeccpars2_104_/1}).
 -compile({nowarn_unused_function,  yeccpars2_104_/1}).
--file("compiler/diameter_dict_parser.yrl", 321).
+-file("compiler/diameter_dict_parser.yrl", 323).
 yeccpars2_104_(__Stack0) ->
  [___1 | __Stack] = __Stack0,
  [begin
@@ -2322,7 +2324,7 @@ yeccpars2_104_(__Stack0) ->
 -compile({inline,yeccpars2_105_/1}).
 -dialyzer({nowarn_function, yeccpars2_105_/1}).
 -compile({nowarn_unused_function,  yeccpars2_105_/1}).
--file("compiler/diameter_dict_parser.yrl", 313).
+-file("compiler/diameter_dict_parser.yrl", 315).
 yeccpars2_105_(__Stack0) ->
  [___6,___5,___4,___3,___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2332,7 +2334,7 @@ yeccpars2_105_(__Stack0) ->
 -compile({inline,yeccpars2_106_/1}).
 -dialyzer({nowarn_function, yeccpars2_106_/1}).
 -compile({nowarn_unused_function,  yeccpars2_106_/1}).
--file("compiler/diameter_dict_parser.yrl", 300).
+-file("compiler/diameter_dict_parser.yrl", 302).
 yeccpars2_106_(__Stack0) ->
  [___4,___3,___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2342,7 +2344,7 @@ yeccpars2_106_(__Stack0) ->
 -compile({inline,yeccpars2_107_/1}).
 -dialyzer({nowarn_function, yeccpars2_107_/1}).
 -compile({nowarn_unused_function,  yeccpars2_107_/1}).
--file("compiler/diameter_dict_parser.yrl", 103).
+-file("compiler/diameter_dict_parser.yrl", 105).
 yeccpars2_107_(__Stack0) ->
  [begin
                                   []
@@ -2351,7 +2353,7 @@ yeccpars2_107_(__Stack0) ->
 -compile({inline,yeccpars2_109_/1}).
 -dialyzer({nowarn_function, yeccpars2_109_/1}).
 -compile({nowarn_unused_function,  yeccpars2_109_/1}).
--file("compiler/diameter_dict_parser.yrl", 62).
+-file("compiler/diameter_dict_parser.yrl", 64).
 yeccpars2_109_(__Stack0) ->
  [___3,___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2361,7 +2363,7 @@ yeccpars2_109_(__Stack0) ->
 -compile({inline,yeccpars2_110_/1}).
 -dialyzer({nowarn_function, yeccpars2_110_/1}).
 -compile({nowarn_unused_function,  yeccpars2_110_/1}).
--file("compiler/diameter_dict_parser.yrl", 103).
+-file("compiler/diameter_dict_parser.yrl", 105).
 yeccpars2_110_(__Stack0) ->
  [begin
                                   []
@@ -2370,7 +2372,7 @@ yeccpars2_110_(__Stack0) ->
 -compile({inline,yeccpars2_111_/1}).
 -dialyzer({nowarn_function, yeccpars2_111_/1}).
 -compile({nowarn_unused_function,  yeccpars2_111_/1}).
--file("compiler/diameter_dict_parser.yrl", 104).
+-file("compiler/diameter_dict_parser.yrl", 106).
 yeccpars2_111_(__Stack0) ->
  [___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2380,7 +2382,7 @@ yeccpars2_111_(__Stack0) ->
 -compile({inline,yeccpars2_112_/1}).
 -dialyzer({nowarn_function, yeccpars2_112_/1}).
 -compile({nowarn_unused_function,  yeccpars2_112_/1}).
--file("compiler/diameter_dict_parser.yrl", 106).
+-file("compiler/diameter_dict_parser.yrl", 108).
 yeccpars2_112_(__Stack0) ->
  [___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2390,7 +2392,7 @@ yeccpars2_112_(__Stack0) ->
 -compile({inline,yeccpars2_113_/1}).
 -dialyzer({nowarn_function, yeccpars2_113_/1}).
 -compile({nowarn_unused_function,  yeccpars2_113_/1}).
--file("compiler/diameter_dict_parser.yrl", 103).
+-file("compiler/diameter_dict_parser.yrl", 105).
 yeccpars2_113_(__Stack0) ->
  [begin
                                   []
@@ -2399,7 +2401,7 @@ yeccpars2_113_(__Stack0) ->
 -compile({inline,yeccpars2_114_/1}).
 -dialyzer({nowarn_function, yeccpars2_114_/1}).
 -compile({nowarn_unused_function,  yeccpars2_114_/1}).
--file("compiler/diameter_dict_parser.yrl", 63).
+-file("compiler/diameter_dict_parser.yrl", 65).
 yeccpars2_114_(__Stack0) ->
  [___3,___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2409,7 +2411,7 @@ yeccpars2_114_(__Stack0) ->
 -compile({inline,yeccpars2_115_/1}).
 -dialyzer({nowarn_function, yeccpars2_115_/1}).
 -compile({nowarn_unused_function,  yeccpars2_115_/1}).
--file("compiler/diameter_dict_parser.yrl", 78).
+-file("compiler/diameter_dict_parser.yrl", 80).
 yeccpars2_115_(__Stack0) ->
  [begin
                          []
@@ -2418,7 +2420,7 @@ yeccpars2_115_(__Stack0) ->
 -compile({inline,yeccpars2_116_/1}).
 -dialyzer({nowarn_function, yeccpars2_116_/1}).
 -compile({nowarn_unused_function,  yeccpars2_116_/1}).
--file("compiler/diameter_dict_parser.yrl", 58).
+-file("compiler/diameter_dict_parser.yrl", 60).
 yeccpars2_116_(__Stack0) ->
  [___3,___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2428,7 +2430,7 @@ yeccpars2_116_(__Stack0) ->
 -compile({inline,yeccpars2_117_/1}).
 -dialyzer({nowarn_function, yeccpars2_117_/1}).
 -compile({nowarn_unused_function,  yeccpars2_117_/1}).
--file("compiler/diameter_dict_parser.yrl", 78).
+-file("compiler/diameter_dict_parser.yrl", 80).
 yeccpars2_117_(__Stack0) ->
  [begin
                          []
@@ -2437,7 +2439,7 @@ yeccpars2_117_(__Stack0) ->
 -compile({inline,yeccpars2_118_/1}).
 -dialyzer({nowarn_function, yeccpars2_118_/1}).
 -compile({nowarn_unused_function,  yeccpars2_118_/1}).
--file("compiler/diameter_dict_parser.yrl", 59).
+-file("compiler/diameter_dict_parser.yrl", 61).
 yeccpars2_118_(__Stack0) ->
  [___3,___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2447,7 +2449,7 @@ yeccpars2_118_(__Stack0) ->
 -compile({inline,yeccpars2_119_/1}).
 -dialyzer({nowarn_function, yeccpars2_119_/1}).
 -compile({nowarn_unused_function,  yeccpars2_119_/1}).
--file("compiler/diameter_dict_parser.yrl", 78).
+-file("compiler/diameter_dict_parser.yrl", 80).
 yeccpars2_119_(__Stack0) ->
  [begin
                          []
@@ -2456,7 +2458,7 @@ yeccpars2_119_(__Stack0) ->
 -compile({inline,yeccpars2_120_/1}).
 -dialyzer({nowarn_function, yeccpars2_120_/1}).
 -compile({nowarn_unused_function,  yeccpars2_120_/1}).
--file("compiler/diameter_dict_parser.yrl", 57).
+-file("compiler/diameter_dict_parser.yrl", 59).
 yeccpars2_120_(__Stack0) ->
  [___3,___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2466,7 +2468,7 @@ yeccpars2_120_(__Stack0) ->
 -compile({inline,yeccpars2_122_/1}).
 -dialyzer({nowarn_function, yeccpars2_122_/1}).
 -compile({nowarn_unused_function,  yeccpars2_122_/1}).
--file("compiler/diameter_dict_parser.yrl", 56).
+-file("compiler/diameter_dict_parser.yrl", 58).
 yeccpars2_122_(__Stack0) ->
  [___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2476,7 +2478,7 @@ yeccpars2_122_(__Stack0) ->
 -compile({inline,yeccpars2_123_/1}).
 -dialyzer({nowarn_function, yeccpars2_123_/1}).
 -compile({nowarn_unused_function,  yeccpars2_123_/1}).
--file("compiler/diameter_dict_parser.yrl", 71).
+-file("compiler/diameter_dict_parser.yrl", 73).
 yeccpars2_123_(__Stack0) ->
  [begin
                                []
@@ -2485,7 +2487,7 @@ yeccpars2_123_(__Stack0) ->
 -compile({inline,yeccpars2_124_/1}).
 -dialyzer({nowarn_function, yeccpars2_124_/1}).
 -compile({nowarn_unused_function,  yeccpars2_124_/1}).
--file("compiler/diameter_dict_parser.yrl", 72).
+-file("compiler/diameter_dict_parser.yrl", 74).
 yeccpars2_124_(__Stack0) ->
  [___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2495,7 +2497,7 @@ yeccpars2_124_(__Stack0) ->
 -compile({inline,yeccpars2_126_/1}).
 -dialyzer({nowarn_function, yeccpars2_126_/1}).
 -compile({nowarn_unused_function,  yeccpars2_126_/1}).
--file("compiler/diameter_dict_parser.yrl", 76).
+-file("compiler/diameter_dict_parser.yrl", 78).
 yeccpars2_126_(__Stack0) ->
  [___1 | __Stack] = __Stack0,
  [begin
@@ -2505,7 +2507,7 @@ yeccpars2_126_(__Stack0) ->
 -compile({inline,yeccpars2_128_/1}).
 -dialyzer({nowarn_function, yeccpars2_128_/1}).
 -compile({nowarn_unused_function,  yeccpars2_128_/1}).
--file("compiler/diameter_dict_parser.yrl", 84).
+-file("compiler/diameter_dict_parser.yrl", 86).
 yeccpars2_128_(__Stack0) ->
  [___1 | __Stack] = __Stack0,
  [begin
@@ -2516,7 +2518,7 @@ yeccpars2_128_(__Stack0) ->
 -compile({inline,yeccpars2_129_/1}).
 -dialyzer({nowarn_function, yeccpars2_129_/1}).
 -compile({nowarn_unused_function,  yeccpars2_129_/1}).
--file("compiler/diameter_dict_parser.yrl", 74).
+-file("compiler/diameter_dict_parser.yrl", 76).
 yeccpars2_129_(__Stack0) ->
  [___4,___3,___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2526,7 +2528,7 @@ yeccpars2_129_(__Stack0) ->
 -compile({inline,yeccpars2_130_/1}).
 -dialyzer({nowarn_function, yeccpars2_130_/1}).
 -compile({nowarn_unused_function,  yeccpars2_130_/1}).
--file("compiler/diameter_dict_parser.yrl", 81).
+-file("compiler/diameter_dict_parser.yrl", 83).
 yeccpars2_130_(__Stack0) ->
  [___1 | __Stack] = __Stack0,
  [begin
@@ -2538,7 +2540,7 @@ yeccpars2_130_(__Stack0) ->
 -compile({inline,yeccpars2_131_/1}).
 -dialyzer({nowarn_function, yeccpars2_131_/1}).
 -compile({nowarn_unused_function,  yeccpars2_131_/1}).
--file("compiler/diameter_dict_parser.yrl", 49).
+-file("compiler/diameter_dict_parser.yrl", 51).
 yeccpars2_131_(__Stack0) ->
  [___2,___1 | __Stack] = __Stack0,
  [begin
@@ -2546,4 +2548,4 @@ yeccpars2_131_(__Stack0) ->
   end | __Stack].
 
 
--file("compiler/diameter_dict_parser.yrl", 329).
+-file("compiler/diameter_dict_parser.yrl", 331).
