@@ -2,14 +2,16 @@
 -module(xmerl_b64Bin).
 -file("xmerl_b64Bin.erl", 3).
 -export([parse/1, parse_and_scan/1, format_error/1]).
--file("xmerl_b64Bin.yrl", 71).
+-file("xmerl_b64Bin.yrl", 73).
 -moduledoc false.
 
--file("/var/tmp/portage/dev-lang/erlang-27.3.4.6/work/otp-OTP-27.3.4.6/bootstrap/lib/parsetools/include/yeccpre.hrl", 0).
+-file("/var/tmp/portage/dev-lang/erlang-28.1/work/otp-OTP-28.1/bootstrap/lib/parsetools/include/yeccpre.hrl", 0).
 %%
 %% %CopyrightBegin%
 %%
-%% Copyright Ericsson AB 1996-2024. All Rights Reserved.
+%% SPDX-License-Identifier: Apache-2.0
+%%
+%% Copyright Ericsson AB 1996-2025. All Rights Reserved.
 %%
 %% Licensed under the Apache License, Version 2.0 (the "License");
 %% you may not use this file except in compliance with the License.
@@ -193,7 +195,7 @@ yecctoken2string1(Other) ->
 
 
 
--file("xmerl_b64Bin.erl", 196).
+-file("xmerl_b64Bin.erl", 198).
 
 -dialyzer({nowarn_function, yeccpars2/7}).
 -compile({nowarn_unused_function,  yeccpars2/7}).
@@ -556,4 +558,4 @@ yeccpars2_17_(__Stack0) ->
   end | __Stack].
 
 
--file("xmerl_b64Bin.yrl", 73).
+-file("xmerl_b64Bin.yrl", 75).
